==> djaodjin_deployutils-0.12.0.tar.gz: djaodjin_deployutils-0.12.0/deployutils/apps/django/management/commands/upload_resources.py <==
# Copyright (c) 2017, Djaodjin Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from __future__ import absolute_import
from __future__ import unicode_literals

import logging, subprocess

from django.conf import settings as django_settings

from ... import settings
from .....copy import upload
from . import ResourceCommand, build_assets


class Command(ResourceCommand):
    help = "Upload resouces to stage."

    def handle(self, *args, **options):
        ResourceCommand.handle(self, *args, **options)
        try:
            build_assets()
            upload(settings.RESOURCES_REMOTE_LOCATION,
                prefix=settings.MULTITIER_RESOURCES_ROOT,
                static_root=django_settings.STATIC_ROOT,
                dry_run=settings.DRY_RUN)
            logging.info("uploaded resources for %s", self.webapp)
        except subprocess.CalledProcessError as err:
            logging.exception(
                "upload_resources %s caught exception: %s", self.webapp, err)

==> djaodjin_deployutils-0.12.2.tar.gz: djaodjin_deployutils-0.12.2/deployutils/apps/django/management/commands/upload_resources.py <==
# Copyright (c) 2017, Djaodjin Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from __future__ import absolute_import
from __future__ import unicode_literals

import logging, subprocess

from django.conf import settings as django_settings

from ... import settings
from .....copy import upload
from .base import ResourceCommand, build_assets


class Command(ResourceCommand):
    help = "Upload resouces to stage."

    def handle(self, *args, **options):
        ResourceCommand.handle(self, *args, **options)
        try:
            build_assets()
            upload(settings.RESOURCES_REMOTE_LOCATION,
                prefix=settings.MULTITIER_RESOURCES_ROOT,
                static_root=django_settings.STATIC_ROOT,
                dry_run=settings.DRY_RUN)
            logging.info("uploaded resources for %s", self.webapp)
        except subprocess.CalledProcessError as err:
            logging.exception(
                "upload_resources %s caught exception: %s", self.webapp, err)
